package App::lcpan::CmdBundle::colortheme;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-11-30'; # DATE
our $DIST = 'App-lcpan-CmdBundle-colortheme'; # DIST
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: lcpan subcommands related to ColorTheme

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::CmdBundle::colortheme - lcpan subcommands related to ColorTheme

=head1 VERSION

This document describes version 0.001 of App::lcpan::CmdBundle::colortheme (from Perl distribution App-lcpan-CmdBundle-colortheme), released on 2020-11-30.

=head1 SYNOPSIS

Install this distribution, then the lcpan subcommands below will be available:

 # List ColorTheme  modules available on CPAN
 % lcpan colortheme-mods

=head1 DESCRIPTION

This bundle provides the following lcpan subcommands:

=over

=item * L<lcpan colortheme-mods|App::lcpan::Cmd::colortheme_mods>

=back

This distribution packages several lcpan subcommands related to
L<ColorTheme>. More subcommands will be added in future releases.

Some ideas:

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-CmdBundle-colortheme>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-colortheme>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-colortheme>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lcpan>

L<ColorTheme>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
